==> linuxcan_5_36_575.tar.gz: linuxcan/doc/HTMLhelp/kvlclib_formats.js <==
var kvlclib_formats =
[
    [ "KME24 (R/W)", "kvlclib_format__k_m_e24.html", null ],
    [ "KME25 (R/W)", "kvlclib_format__k_m_e25.html", null ],
    [ "KME40 (R/W)", "kvlclib_format__k_m_e40.html", null ],
    [ "KME50 (R/W)", "kvlclib_format__k_m_e50.html", null ],
    [ "Vector BLF FD (R/W)", "kvlclib_format__v_e_c_t_o_r__b_l_f__f_d.html", [
      [ "Supported properties", "kvlclib_format__v_e_c_t_o_r__b_l_f__f_d.html#kvlclib_section_vectorblffd_supported_properties", null ],
      [ "Supported object types", "kvlclib_format__v_e_c_t_o_r__b_l_f__f_d.html#kvlclib_section_vectorblffd_supported_object_types", null ],
      [ "Notes", "kvlclib_format__v_e_c_t_o_r__b_l_f__f_d.html#kvlclib_section_vectorblffd_notes", null ]
    ] ],
    [ "Vector BLF (W)", "kvlclib_format__v_e_c_t_o_r__b_l_f.html", null ],
    [ "Vector ASCII (R/W)", "kvlclib_format__v_e_c_t_o_r__a_s_c.html", null ],
    [ "CSV Frame (W)", "kvlclib_format__f_o_r_m_a_t__c_s_v.html", null ],
    [ "Plain text (R/W)", "kvlclib_format__p_l_a_i_n__a_s_c.html", null ],
    [ "MDF (R/W)", "kvlclib_format__f_o_r_m_a_t__m_d_f.html", null ],
    [ "MDF Signal (W)", "kvlclib_format__m_d_f__s_i_g_n_a_l.html", null ],
    [ "MDF v4.1 (R/W)", "kvlclib_format__m_d_f_4_x.html", [
      [ "Supported properties", "kvlclib_format__m_d_f_4_x.html#kvlclib_section_mdf4_supported_properties", null ]
    ] ],
    [ "MDF v4.1 Signal (W)", "kvlclib_format__m_d_f_4_x__s_i_g_n_a_l.html", [
      [ "Supported properties", "kvlclib_format__m_d_f_4_x__s_i_g_n_a_l.html#kvlclib_section_mdf4signal_supported_properties", null ]
    ] ],
    [ "Matlab (W)", "kvlclib_format__m_a_t_l_a_b.html", null ],
    [ "ASCII J1587  (W)", "kvlclib_format__j1587.html", null ]
];

==> linuxcan_5_37_686.tar.gz: linuxcan/doc/HTMLhelp/kvlclib_formats.js <==
var kvlclib_formats =
[
    [ "KME24 (R/W)", "kvlclib_format__k_m_e24.html", null ],
    [ "KME25 (R/W)", "kvlclib_format__k_m_e25.html", null ],
    [ "KME40 (R/W)", "kvlclib_format__k_m_e40.html", null ],
    [ "KME50 (R/W)", "kvlclib_format__k_m_e50.html", null ],
    [ "Vector BLF FD (R/W)", "kvlclib_format__v_e_c_t_o_r__b_l_f__f_d.html", [
      [ "Supported properties", "kvlclib_format__v_e_c_t_o_r__b_l_f__f_d.html#kvlclib_section_vectorblffd_supported_properties", null ],
      [ "Supported object types", "kvlclib_format__v_e_c_t_o_r__b_l_f__f_d.html#kvlclib_section_vectorblffd_supported_object_types", null ],
      [ "Notes", "kvlclib_format__v_e_c_t_o_r__b_l_f__f_d.html#kvlclib_section_vectorblffd_notes", null ]
    ] ],
    [ "Vector BLF (W)", "kvlclib_format__v_e_c_t_o_r__b_l_f.html", null ],
    [ "Vector ASCII (R/W)", "kvlclib_format__v_e_c_t_o_r__a_s_c.html", null ],
    [ "CSV Frame (W)", "kvlclib_format__f_o_r_m_a_t__c_s_v.html", null ],
    [ "CSV Signal (W)", "kvlclib_format__f_o_r_m_a_t__c_s_v__s_i_g_n_a_l.html", null ],
    [ "Plain text (R/W)", "kvlclib_format__p_l_a_i_n__a_s_c.html", null ],
    [ "MDF (R/W)", "kvlclib_format__f_o_r_m_a_t__m_d_f.html", null ],
    [ "MDF Signal (W)", "kvlclib_format__m_d_f__s_i_g_n_a_l.html", null ],
    [ "MDF v4.1 (R/W)", "kvlclib_format__m_d_f_4_x.html", [
      [ "Supported properties", "kvlclib_format__m_d_f_4_x.html#kvlclib_section_mdf4_supported_properties", null ]
    ] ],
    [ "MDF v4.1 Signal (W)", "kvlclib_format__m_d_f_4_x__s_i_g_n_a_l.html", [
      [ "Supported properties", "kvlclib_format__m_d_f_4_x__s_i_g_n_a_l.html#kvlclib_section_mdf4signal_supported_properties", null ]
    ] ],
    [ "Matlab (W)", "kvlclib_format__m_a_t_l_a_b.html", null ],
    [ "ASCII J1587  (W)", "kvlclib_format__j1587.html", null ],
    [ "FAMOS (W)", "kvlclib_format__f_a_m_o_s.html", null ],
    [ "DIAdem DAT (W)", "kvlclib_format__d_i_a_d_e_m.html", null ],
    [ "MTS RPC III (W)", "kvlclib_format__r_p_c_i_i_i.html", null ]
];
